| Title: | Create Sliders for 'Shiny' |
|---|---|
| Description: | Create sliders from left, right, top and bottom which may include any html or 'Shiny' input or output. |
| Authors: | John Coene [aut, cre] |
| Maintainer: | John Coene <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-13 05:36:28 UTC |
| Source: | https://github.com/johncoene/pushbar |
Set up pushbar.
Creates element containing pushbar content.
pushbar_deps() setup_pushbar(blur = FALSE, overlay = TRUE, esc_close = TRUE) pushbar( ..., id = from, from = c("left", "right", "top", "bottom"), class = NULL, style = pushbar_style() )pushbar_deps() setup_pushbar(blur = FALSE, overlay = TRUE, esc_close = TRUE) pushbar( ..., id = from, from = c("left", "right", "top", "bottom"), class = NULL, style = pushbar_style() )
blur |
Whether to blur the background when pushbar is opened. |
overlay |
Whether to darken the background when pushbar is opened. |
esc_close |
Whether to enable pressing 'ESC' key to close the pushbar |
... |
Any other valid tags. |
id |
Id of pushbar. |
from |
Wherefrom the pushbar should open. |
class |
Additional class to pass to |
style |
Valid css defaults to |
Creates a div.
You are advised to add padding inside your pushbar i.e.: style="padding:20px;"
library(shiny) ui <- fluidPage( pushbar_deps(), actionButton("open", "Open pushbar"), pushbar( h4("HELLO") ) ) server <- function(input, output, session){ setup_pushbar() observeEvent(input$open, { pushbar_open() }) } if(interactive()) shinyApp(ui, server)library(shiny) ui <- fluidPage( pushbar_deps(), actionButton("open", "Open pushbar"), pushbar( h4("HELLO") ) ) server <- function(input, output, session){ setup_pushbar() observeEvent(input$open, { pushbar_open() }) } if(interactive()) shinyApp(ui, server)
Open and close pushbar programatically.
pushbar_open(id = c("left", "right", "top", "bottom")) pushbar_close()pushbar_open(id = c("left", "right", "top", "bottom")) pushbar_close()
id |
Id of pushbar to open. |